@@ -22,6 +22,7 @@ has 'loginPassword' => (is => 'rw', isa => 'Str');
 
 has 'loginName' => (is => 'rw', isa => 'Str',
 		    documentation => 'login name - must be unique');
+__PACKAGE__->_alias(userName => 'loginName');
 		    
 has 'email' => (is => 'rw', isa => 'Str',
 		documentation => 'users email address');
@@ -66,9 +67,9 @@ coerce 'Elive::Entity::User' => from 'Str'
 =cut
 
 sub _readback_check {
-    my ($class, $update_href, @args) = @_;
+    my ($class, $update_ref, $rows, @args) = @_;
 
-    my %updates = %$update_href;
+    my %updates = %$update_ref;
 
     #
     # password not included in readback record - skip it
@@ -76,7 +77,7 @@ sub _readback_check {
 
     delete $updates{loginPassword};
 
-    return $class->SUPER::_readback_check(\%updates, @args, case_insensitive => 1);
+    return $class->SUPER::_readback_check(\%updates, $rows, @args, case_insensitive => 1);
 }
 
 =head2 get_by_loginName
@@ -98,7 +99,6 @@ sub get_by_loginName {
     # The entity name is loginName, but the fetch key is userName.
     #
     my $results = $class->_fetch({userName => $loginName},
-				 readback => {loginName => $loginName},
 				 @args,
 	);
 
